Template tags
=============

AlekSIS provides some templatetags to display data in templates.

Dashboard
---------

.. automodule:: aleksis.core.templatetags.dashboard
   :members:

Data helpers
------------

.. automodule:: aleksis.core.templatetags.data_helpers
   :members:

HTML helpers
------------

.. automodule:: aleksis.core.templatetags.html_helpers
   :members:
